#
# spec file for package yodl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yodl
Version:        4.01.00
Release:        lp150.1.28
Summary:        Yet One-other Document Language
License:        GPL-3.0
Group:          Development/Tools/Doc Generators
Url:            https://fbb-git.github.io/yodl/
Source:         https://github.com/fbb-git/yodl/archive/%{version}.tar.gz
Patch0:         %{name}-doc-packages.patch
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  grep
BuildRequires:  icmake
BuildRequires:  sed
BuildRequires:  texlive-latex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1220
BuildRequires:  texlive-collection-binextra
BuildRequires:  texlive-collection-latex
BuildRequires:  tex(a4.sty)
BuildRequires:  tex(epsf.sty)
%else
BuildRequires:  texlive-bin
%endif

%description
YODL is a package that consists of programs, some shell scripts, and
auxiliary "lib" files for which hold macro files. The whole purpose of
the package is to provide a simple-to-use and extensible document
language that can be used to convert documents in the YODL format to a
variety of other formats. In this purpose, YODL somewhat resembles
generic markup languages.

%prep
%setup -q
%patch0

sed -i s,"#define COPT.*","#define COPT \"%{optflags}\"", ./yodl/build

%build
pushd yodl
./build programs
./build macros
./build manual
./build man
popd

%install
pushd yodl
cp -a tmp/install/* %{buildroot}
chmod +x %{buildroot}%{_bindir}/yodl2whatever
(cd %{buildroot}%{_bindir}; for i in html latex man ms sgml txt xml; do ln -s yodl2whatever yodl2$i; done)
popd

rm -f %{buildroot}%{_docdir}/yodl.dvi
rm -f %{buildroot}%{_docdir}/yodl.latex
rm -f %{buildroot}%{_docdir}/yodl.txt

%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%doc yodl/AUTHORS.txt yodl/changelog yodl/README.* yodl/CHANGES
%doc %{_docdir}/%{name}/
%{_bindir}/yodl
%{_bindir}/yodl2html
%{_bindir}/yodl2latex
%{_bindir}/yodl2man
%{_bindir}/yodl2ms
%{_bindir}/yodl2sgml
%{_bindir}/yodl2txt
%{_bindir}/yodl2whatever
%{_bindir}/yodl2xml
%{_bindir}/yodlpost
%{_bindir}/yodlstriproff
%{_bindir}/yodlverbinsert
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_mandir}/man1/yodl.1%{ext_man}
%{_mandir}/man1/yodlconverters.1%{ext_man}
%{_mandir}/man1/yodlpost.1%{ext_man}
%{_mandir}/man1/yodlstriproff.1%{ext_man}
%{_mandir}/man1/yodlverbinsert.1%{ext_man}
%{_mandir}/man7/yodlbuiltins.7%{ext_man}
%{_mandir}/man7/yodlletter.7%{ext_man}
%{_mandir}/man7/yodlmacros.7%{ext_man}
%{_mandir}/man7/yodlmanpage.7%{ext_man}

%changelog
* Mon Dec 18 2017 pgajdos@suse.com
- update to 4.01.00:
  * Fixed flaw in handling the LaTex chartable's SUBST(--) definition and
    occurrences of -- in, e.g., letteradmin.raw.
  * The LaTeX specific way of handling two dashes is available, outside of
    NOEXPAND environments as used by, e.g., the verb() and tt() macros, is
    available through the new `dashes()' macro.
  * New macros ttbegin() and ttend() can be used to fine-tune how text set in
    teletype font is handled, in particular in LaTeX conversions.
  * Added builtin functions PUSHSUBST and POPSUBST, as well as the (internally
    used) builtin function XXSUBST.
  * Removed old macros and builtin commands, obsoleted since Yodl 2.00.00.
    (see also the manual section `what's new in 4.00.00').
  * The predefined macro `verb(...)'  now starts with PUSHSUBST(0) and ends
    with POPSUBST: SUBST definitions are not interpreted anymore inside a
    'verb()' macro (SUBST definitions were already ignored in files inserted
    by the NOEXAPAND(PATH)INCLUDE builtin commands).
  * The original definition of the `verb(...)' macro remains available in the
    new predefined macro `verborg(...)'.
  * The contents of the formerly used ./yo subdirectory of ./manual are now
    in ./manual; ./yo has been removed.
  * In LaTeX conversions the -- sequence is now defined in a SUBST definition
    in macros/yodl/chartables/latex.tables.yo as
    SUBST(--)(+NOTRANS(-{}-{}))
    due to which text like `operator--()' now clearly shows the two minus
    characters (single minus chars are OK, and cannot be translated, because
    LaTeX sometimes uses them in expressions like `\cline{1-4}').
  * Documentation was updated.
* Mon May 29 2017 pgajdos@suse.com
- updated to 3.10.00:
  * Redefined some elements in the standard LaTeX translation table:
    no-argument macros like
    '|'     = "\\textbar"
    received an empty parameter box ("\\textbar{}") to avoid subsequent blanks
    being consumed by LaTex. Cf.,
    https://tex.stackexchange.com/questions/31091/space-after-latex-commands
  * Added a new macro `tableatt' using the attributes specified at the last
    `attrib' macro call to set html-attributes for the html `<table>' tag.
* Wed May 10 2017 mpluskal@suse.com
- Update to version 3.08.02:
  * Reorganized the yodl-manpage macro (macros/rawmacros/manpage.raw):
    + man-pages can now be converted to roff, html, and plain text
    format.
    + References to the todl manual page format in Yodl's user
    guide and man-pages were updated accordingly.
  * The reorganization also fixes a bug in the manpage html
    conversion.
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly package %%{_docdir}/%%{name} to fix build with RPM 4.13.
* Mon Nov 21 2016 pgajdos@suse.com
- Update to 3.08.01:
  * See https://fbb-git.github.io/yodl/changelog.txt
* Tue Jan 12 2016 mpluskal@suse.com
- Update to 3.06.00
  * No changelog available
* Sun Sep 20 2015 mpluskal@suse.com
- Update to 3.05.01
  * The chartables defined in latex.tables.yo now surround <, >
    and * characters by $s (e.g., $<$), preventing LaTeX from
    processing them in a special way (e.g., forming ligatures like
    one character for >>).
  * Added the file `required' listing the non-standard software
    that is required to build yodl and its user guide
- Update project and download url
* Sat Mar 28 2015 mpluskal@suse.com
- Update to 3.05
  * Html conversion by default uses html5, and generates html5
    type html pages, several macros were adapted accordingly.
  * New macros (use `man yodlmacros' for their definitions):
    + attrib
    + htmlheadfile
    + htmlstyle
    + nohtmlfive
    + nohtmlimgstyle
    + sethtmlmetacharset
  * Modified macros:
    + @counters
    + @symbols
    + center
    + dit
    + endcenter
    + figure
    + htmlbodyopt - deprecated
    + htmlheadopt
    + htmlstylesheet
    + itdesc
    + notocclearpage
    + sc
    + startcenter
    + strong
    + tt
- Cleanup spec file with spec-cleaner
* Tue Nov 18 2014 pgajdos@suse.com
- updated to 3.04:
  * The redef() and redefinemacro() descriptions missed the name of the macro
    to be redefined: they require 3 instead of 2 args.
  * The yodlverbinsert program is now C++, and supports -a: process all lines
    and -n: prefix lines by numbers. Yodlverbinsert ignores initial and
    trailing blank lines.
  * Removed some compiler warnings.
* Wed Nov 27 2013 pgajdos@suse.com
- updated to 3.03:
  * bugfixes
  * see changelog for details
- fix-path.patch renamed to yodl-doc-packages.patch
- fix-tex-include.patch merged into yodl-doc-packages.patch as
  changes in both patches relate
* Thu Apr 18 2013 werner@suse.de
- Make it build with openSUSE >= 12.2
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Jan 14 2013 idonmez@suse.com
- Use %%{optflags}
* Wed Dec 12 2012 kkaempf@suse.com
- Update to 3.00.0
  To get the pre-3.00.0 include behavior, use the -L
  (--legacy-include) option
  2.00.0 was a complete rewrite. See the manual for the modifications.
  Old yodl-sources will usually require minor modifications
  See /usr/share/doc/packages/yodl/CHANGES
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit makeinfo dependency
- Format spec file
* Sat Apr 21 2007 aj@suse.de
- Use texlive.
* Thu Mar 29 2007 meissner@suse.de
- added bison,flex
* Tue Nov  7 2006 meissner@suse.de
- use RPM_OPT_FLAGS
* Tue Sep 26 2006 cthiel@suse.de
- fix build with python 2.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
* Tue Feb 17 2004 postadal@suse.cz
- added includes to avoid warnings in code
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Wed Feb 26 2003 postadal@suse.cz
- used install-info macros (with section and dir entry)
* Wed Nov 15 2000 vinil@suse.cz
- regrouped
- CHANGES added
- buildroot used better
* Thu Apr 20 2000 vinil@suse.cz
- buildroot added
* Fri Jan 21 2000 ro@suse.de
- update to 1.31.18, move info,man to usr/share
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Oct 28 1998 ro@suse.de
- switch used default groff-macro from gs to s
* Thu Sep 24 1998 ro@suse.de
- initial package v 1.31.5
